@@ -117,7 +117,7 @@ class FreqDict(models.Model):
 
 
     def addCategories(self,lemmas):
-        with open(fetch_celex_resource('Syntax/celex-syntax-lemmas.txt'),'r') as f:
+        with open(fetch_celex_resource('Category/celex-syntax-lemmas.txt'),'r') as f:
             head = None
             for line in f:
                 l = line.strip().split("//")
