@@ -1,6 +1,7 @@
 
 import csv
 
+from django.core.management import call_command
 from django.core.context_processors import csrf
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth import authenticate,login
@@ -11,8 +12,7 @@ from django.core.files import File
 
 from .models import *
 from .forms import *
-from .helper import fetch_celex_resource,reset
-
+from .helper import fetch_celex_resource
 
 #old
 #call_command('reset','stimuli', interactive=False,verbosity=0)
@@ -52,13 +52,16 @@ def index(request):
     return render(request,'celex/index.html',{})
 
 
+
 @login_required
 def reset(request):
     if request.user.is_superuser:
         if request.method == 'POST':
             form = ResetForm(request.POST)
             if form.is_valid() and form.cleaned_data['reset']:
-                reset()
+                call_command('south_clear','celex', interactive=False,verbosity=0)
+                c = FreqDict.objects.create(Name='CELEX')
+                c.loadInfo()
                 return redirect(index)
             else:
                 form = ResetForm()
